//
//  HTTPConnection.h
//  iStrip
//
//  Created by Joar Wingfors on 2005-01-07.
//  Copyright 2005 joar.com. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "StripOperationProgress.h"

@class HTTPConnection;

@protocol HTTPConnectionDelegate
- (void) connection:(HTTPConnection *) connection abortedWithError:(StripOperationErrorCode) error description:(NSString *) description;
- (void) connection:(HTTPConnection *) connection didUpdateProgress:(StripOperationProgress *) progress;
- (void) connection:(HTTPConnection *) connection didDownloadData:(NSData *) data;
@end

typedef enum _HTTPConnectionState
{
	HTTPConnectionState_Invalid,
	HTTPConnectionState_Pending,
	HTTPConnectionState_Downloading,
	HTTPConnectionState_Completed
} HTTPConnectionState;

@interface HTTPConnection : NSObject
{
	@private
	
	NSURL *myURL;
	NSString *myReferrer;
	id < HTTPConnectionDelegate > myDelegate; // Weak reference
	id myContext;
	
	NSURLConnection *myConnection;
	unsigned int myExpectedLength;
	NSMutableData *myData;
	
	HTTPConnectionState myState;
}

+ (unsigned int) defaultMaxNumberOfOpenConnections;
+ (unsigned int) minNumberOfOpenConnections;
+ (void) setMaxNumberOfOpenConnections:(unsigned int) count;
+ (unsigned int) maxNumberOfOpenConnections;

// The delegate is not retained, byt the context object is.
// References to both delegate and context object is cleared if the cancelDownload method is called.
- (void) downloadURL:(NSURL *) url withReferrer:(NSString *) referrer delegate:(id < HTTPConnectionDelegate >) delegate context:(id) context;
- (void) cancelDownload;

- (NSURL *) URL; // Note: Can be different than original if re-directed!
- (id) context;

@end
