//
//  PreloadController.h
//  iStrip
//
//  Created by Joar Wingfors on 2005-02-14.
//  Copyright 2005 joar.com. All rights reserved.
//

#import "StripProtocol.h"

@class HTTPConnection;

@protocol PreloadControllerDelegate
- (void) preloadWillStart;
- (void) preloadDidCancelWithReason:(NSString *) reason;
- (void) preloadDidFailWithError:(StripOperationErrorCode) error description:(NSString *) description;
- (void) preloadDidUpdateProgress:(StripOperationProgress *) progress;
- (void) preloadDidDownloadPage:(NSString *) html;
- (void) preloadDidComplete;
@end

typedef enum _PreloadControllerState
{
	PreloadControllerState_None,					// Not done
	PreloadControllerState_InProgress_Idle,			// In progress, currently idle
	PreloadControllerState_InProgress_Downloading,	// In progress, currently downloading
	PreloadControllerState_Done,					// Preloaded
	PreloadControllerState_Error					// Fatal error
} PreloadControllerState;
	
@interface PreloadController : NSObject
{
	@private
	
	id myPreloadedObjects;
	id < PreloadControllerDelegate > myDelegate;

    HTTPConnection *myHTTPConnection;
	PreloadControllerState myPreloadControllerState;
	
	NSMutableIndexSet *myValues;
}

- (id) initWithDelegate:(id < PreloadControllerDelegate >) delegate;

- (void) setPreloadedObjects:(id) objs;
- (id) preloadedObjects;

- (void) setDelegate:(id < PreloadControllerDelegate >) delegate;
- (id) delegate;

- (void) willStartPreload; // Required: Call before launching new preload
- (void) loadFromURL:(NSURL *) url; // Call to request download of HTML
- (void) cancelPreloadWithReason:(NSString *) reason;
- (void) abortPreloadWithUnknownError; // Required: Call if preload fails
- (void) preloadDidComplete; // Required: Call once preload is done
- (void) clearPreload;

- (BOOL) isPreloading;
- (BOOL) isPreloaded;

@end

@interface PreloadController (Strip_Private)

- (BOOL) containsValue:(StripValue) value;
- (void) addValue:(StripValue) value;
- (void) addValuesInRange:(NSRange) valueRange;
- (void) removeAllValues;
- (unsigned int) numberOfValues;

- (StripValue) firstValue;
- (StripValue) lastValue;

- (StripValue) nextValueSmallerThanValue:(StripValue) value;
- (StripValue) nextValueGreaterThanValue:(StripValue) value;

- (NSData *) archivedValues;
- (void) setArchivedValues:(NSData *) data;

@end

@interface DatePreloadController : PreloadController

- (void) setHaveDate:(NSCalendarDate *) date;

@end

@interface IndexPreloadController : PreloadController

- (void) setHaveIndex:(unsigned int) index;
- (void) setHaveRangeBetweenFirstIndex:(unsigned int) firstIndex lastIndex:(unsigned int) lastIndex;

@end
