//
//  StripOperationProgress.h
//  iStrip
//
//  Created by Joar Wingfors on 2006-08-26.
//  Copyright 2006 joar.com. All rights reserved.
//

#import <Foundation/Foundation.h>

typedef enum _StripOperationErrorCode
{
	StripOperationError_Generic,		// Catch all...
	StripOperationError_UserInitiated	// Operation aborted in response to user action (Sleep, Termination, etc.)
} StripOperationErrorCode;

@interface StripOperationProgress : NSObject < NSCopying >
{
	@private

	unsigned int myPercentage;
	
	BOOL myIsIndeterminateFlag;
	BOOL myHasOverflowFlag;
	
	unsigned int myCurrentStep;
	unsigned int myNumberOfSteps;
}

// Return indeterminate progress
+ (id) progressIndeterminate;

// Return progress given the current and total values of an operation
+ (id) progressFromCurrent:(unsigned int) current ofTotal:(unsigned int) total acceptingOverflow:(BOOL) canOverflow;

// Given the progress of one step in an operation, return the current progress for the whole operation
+ (id) progressFromProgress:(StripOperationProgress *) progress atStep:(unsigned int) step ofTotal:(unsigned int) total;

// The percent completed of an operation. Values are in the range [0 - 100].
- (unsigned int) percentage;

// Signifies that progress cannot be determined
- (BOOL) isIndeterminate;

// Signifies that, because of some error, progress extended beyond the expected
- (BOOL) hasOverflow;

// Information about progress of an operation comprised of many steps
- (unsigned int) currentStep;
- (unsigned int) numberOfSteps;

@end
